==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/ClientBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class ClientBean extends com.jurismarches.vradi.entities.QueryMakerBean implements Client, QueryMaker {

    private static final long serialVersionUID = -930237897L;

    public ClientBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Client$name;

     public String Client$email;

     public Date Client$creationDate;

     public boolean Client$validEmail;

     public String Client$address;

     public String Client$phone;

     public String Client$contact;

     public Set<String> Client$group;

     public Set<String> Client$user;

     public Set<String> Client$sending;

 
    public void setName(String value) {
        Object oldValue = Client$name; 
        this.Client$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Client$name;
    }


    public void setEmail(String value) {
        Object oldValue = Client$email; 
        this.Client$email = value;
        propertyChange.firePropertyChange("email", oldValue, value);
    }

    public String getEmail() {
        return Client$email;
    }


    public void setCreationDate(Date value) {
        Object oldValue = Client$creationDate; 
        this.Client$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return Client$creationDate;
    }


    public void setValidEmail(boolean value) {
        Object oldValue = Client$validEmail; 
        this.Client$validEmail = value;
        propertyChange.firePropertyChange("validEmail", oldValue, value);
    }

    public boolean getValidEmail() {
        return Client$validEmail;
    }


    public void setAddress(String value) {
        Object oldValue = Client$address; 
        this.Client$address = value;
        propertyChange.firePropertyChange("address", oldValue, value);
    }

    public String getAddress() {
        return Client$address;
    }


    public void setPhone(String value) {
        Object oldValue = Client$phone; 
        this.Client$phone = value;
        propertyChange.firePropertyChange("phone", oldValue, value);
    }

    public String getPhone() {
        return Client$phone;
    }


    public void setContact(String value) {
        Object oldValue = Client$contact; 
        this.Client$contact = value;
        propertyChange.firePropertyChange("contact", oldValue, value);
    }

    public String getContact() {
        return Client$contact;
    }

    public Set<String> getGroup() {
        return Client$group;
    }

    public void addGroup(String element) {
        Client$group.add(element);
        propertyChange.firePropertyChange("group", null, Client$group);
    }
    
    public void removeGroup(String element) {
        Client$group.remove(element);
        propertyChange.firePropertyChange("group", null, Client$group);
    }
    
    public void clearGroup() {
        Client$group.clear();
        propertyChange.firePropertyChange("group", null, Client$group);
    }

    public Set<String> getUser() {
        return Client$user;
    }

    public void addUser(String element) {
        Client$user.add(element);
        propertyChange.firePropertyChange("user", null, Client$user);
    }
    
    public void removeUser(String element) {
        Client$user.remove(element);
        propertyChange.firePropertyChange("user", null, Client$user);
    }
    
    public void clearUser() {
        Client$user.clear();
        propertyChange.firePropertyChange("user", null, Client$user);
    }

    public Set<String> getSending() {
        return Client$sending;
    }

    public void addSending(String element) {
        Client$sending.add(element);
        propertyChange.firePropertyChange("sending", null, Client$sending);
    }
    
    public void removeSending(String element) {
        Client$sending.remove(element);
        propertyChange.firePropertyChange("sending", null, Client$sending);
    }
    
    public void clearSending() {
        Client$sending.clear();
        propertyChange.firePropertyChange("sending", null, Client$sending);
    }

    public Set<String> QueryMaker$queries;

     public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //ClientBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/ClientBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import org.sharengo.wikitty.BusinessEntityBean;

public class ClientBean extends com.jurismarches.vradi.entities.QueryMakerBean implements Client, QueryMaker {

    private static final long serialVersionUID = -88940554L;

    public ClientBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Client$name;

    public Date Client$creationDate;

    public String Client$address;

    public String Client$phone;

    public String Client$contact;


    public void setName(String value) {
        Object oldValue = Client$name; 
        this.Client$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Client$name;
    }


    public void setCreationDate(Date value) {
        Object oldValue = Client$creationDate; 
        this.Client$creationDate = value;
        propertyChange.firePropertyChange("creationDate", oldValue, value);
    }

    public Date getCreationDate() {
        return Client$creationDate;
    }


    public void setAddress(String value) {
        Object oldValue = Client$address; 
        this.Client$address = value;
        propertyChange.firePropertyChange("address", oldValue, value);
    }

    public String getAddress() {
        return Client$address;
    }


    public void setPhone(String value) {
        Object oldValue = Client$phone; 
        this.Client$phone = value;
        propertyChange.firePropertyChange("phone", oldValue, value);
    }

    public String getPhone() {
        return Client$phone;
    }


    public void setContact(String value) {
        Object oldValue = Client$contact; 
        this.Client$contact = value;
        propertyChange.firePropertyChange("contact", oldValue, value);
    }

    public String getContact() {
        return Client$contact;
    }

    public java.util.Set<String> QueryMaker$queries;

    public java.util.Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //ClientBean
